@@ -1,16 +1,10 @@
 package Acme::PERLANCAR::Test;
 
-our $DATE = '2015-06-14'; # DATE
-our $VERSION = '0.25'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
 
 1;
-# ABSTRACT: Distribution to test various things
-
-__END__
 
 =pod
 
@@ -22,7 +16,7 @@ Acme::PERLANCAR::Test - Distribution to test various things
 
 =head1 VERSION
 
-This document describes version 0.25 of Acme::PERLANCAR::Test (from Perl distribution Acme-PERLANCAR-Test), released on 2015-06-14.
+This document describes version 0.26 of Acme::PERLANCAR::Test (from Perl distribution Acme-PERLANCAR-Test), released on 2015-07-27.
 
 =head1 DESCRIPTION
 
@@ -57,3 +51,11 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+__END__
+# ABSTRACT: Distribution to test various things
+
+# DATE
+# DIST
+# VERSION
+
